@@ -10,12 +10,13 @@ from zipline.utils.tradingcalendar import get_trading_days
 import datetime
 from financial_fundamentals import prices
 from financial_fundamentals.sqlite_drivers import SQLiteTimeseries
-import sqlite3
+
 from financial_fundamentals.mongo_drivers import MongoTimeseries
 from financial_fundamentals.exceptions import NoDataForStock,\
-    ExternalRequestFailed
+    ExternalRequestFailed, NoDataForStockOnDate
 import warnings
 import numpy as np
+from numbers import Number
 
 def _load_from_cache(cache,
                     indexes={},
@@ -94,7 +95,7 @@ class FinancialDataTimeSeriesCache(object):
                                  sqlite_file_path, 
                                  table='prices', 
                                  metric='Adj Close'):
-        connection = sqlite3.connect(sqlite_file_path)
+        connection = SQLiteTimeseries.connect(sqlite_file_path)
         db = SQLiteTimeseries(connection=connection, 
                               table=table, 
                               metric=metric)
@@ -114,8 +115,8 @@ class FinancialDataTimeSeriesCache(object):
     
     
 class FinancialDataRangesCache(object):
-    def __init__(self, gets_data, database):
-        self._get_data = gets_data
+    def __init__(self, get_data, database):
+        self._get_data = get_data
         self._database = database
         
     def get(self, symbol, dates):
@@ -127,14 +128,45 @@ class FinancialDataRangesCache(object):
             # Not looking for more than one date at a time because the set
             # operation will set multiple dates per call.
             cached_value = self._database.get(symbol=symbol, date=date)
-            if cached_value:
-                yield date, cached_value
+            if isinstance(cached_value, Number):
+                yield cached_value
             else:
-                yield date, self._get_set(symbol=symbol, date=date)
+                yield self._get_set(symbol=symbol, date=date)
     
     def _get_set(self, symbol, date):
+        print 'cache miss', symbol, date
         start, value, end = self._get_data(symbol=symbol, date=date)
-        self._database.set_interval(symbol=symbol, start=start, end=end, value=value)
+        start = start and datetime.datetime(start.year, 
+                                            start.month, 
+                                            start.day, 
+                                            tzinfo=pytz.UTC)
+        end = end and datetime.datetime(end.year, 
+                                        end.month, 
+                                        end.day, 
+                                        tzinfo=pytz.UTC)
+        self._database.set_interval(symbol=symbol, 
+                                    start=start, 
+                                    end=end, 
+                                    value=value)
         return value
 
-    load_from_cache = _load_from_cache
+    def load_from_cache(self, 
+                        stocks, 
+                        start=pd.datetime(1990, 1, 1, 0, 0, 0, 0, pytz.utc),
+                        end=datetime.datetime.now().replace(tzinfo=pytz.utc)):
+        assert start <= end, 'start must be before end'
+        datetime_index = get_trading_days(start=start, end=end)
+        df = pd.DataFrame(index=datetime_index)
+        python_datetimes = list(datetime_index.to_pydatetime())
+        for symbol in stocks:
+            try:
+                values = self.get(symbol=symbol, dates=python_datetimes)
+                series = pd.Series(data=values, index=datetime_index)
+            except (NoDataForStock, NoDataForStockOnDate):
+                warnings.warn('No data for {}'.format(symbol))
+            except ExternalRequestFailed as e:
+                warnings.warn('Getting data for {} failed {}'.format(symbol,
+                                                                     e.message))
+            else:
+                df[symbol] = series
+        return df
\ No newline at end of file
